=============
API Reference
=============

:Release: |version|
:Date: |today|

This shows the details of the API of HighIQ. Documentation
of each procedure in each module is provided as a reference.

.. toctree::
   :maxdepth: 4

   calc
   io
   vis
